@@ -45,7 +45,7 @@ namespace Model
   class LaunchTemplateSpecificationOverride
   {
   public:
-    AWS_BATCH_API LaunchTemplateSpecificationOverride();
+    AWS_BATCH_API LaunchTemplateSpecificationOverride() = default;
     AWS_BATCH_API LaunchTemplateSpecificationOverride(Aws::Utils::Json::JsonView jsonValue);
     AWS_BATCH_API LaunchTemplateSpecificationOverride& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_BATCH_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -57,14 +57,12 @@ namespace Model
      * <code>launchTemplateId</code> you can't specify the
      * <code>launchTemplateName</code> as well.</p>
      */
-    inline const Aws::String& GetLaunchTemplateId() const{ return m_launchTemplateId; }
+    inline const Aws::String& GetLaunchTemplateId() const { return m_launchTemplateId; }
     inline bool LaunchTemplateIdHasBeenSet() const { return m_launchTemplateIdHasBeenSet; }
-    inline void SetLaunchTemplateId(const Aws::String& value) { m_launchTemplateIdHasBeenSet = true; m_launchTemplateId = value; }
-    inline void SetLaunchTemplateId(Aws::String&& value) { m_launchTemplateIdHasBeenSet = true; m_launchTemplateId = std::move(value); }
-    inline void SetLaunchTemplateId(const char* value) { m_launchTemplateIdHasBeenSet = true; m_launchTemplateId.assign(value); }
-    inline LaunchTemplateSpecificationOverride& WithLaunchTemplateId(const Aws::String& value) { SetLaunchTemplateId(value); return *this;}
-    inline LaunchTemplateSpecificationOverride& WithLaunchTemplateId(Aws::String&& value) { SetLaunchTemplateId(std::move(value)); return *this;}
-    inline LaunchTemplateSpecificationOverride& WithLaunchTemplateId(const char* value) { SetLaunchTemplateId(value); return *this;}
+    template<typename LaunchTemplateIdT = Aws::String>
+    void SetLaunchTemplateId(LaunchTemplateIdT&& value) { m_launchTemplateIdHasBeenSet = true; m_launchTemplateId = std::forward<LaunchTemplateIdT>(value); }
+    template<typename LaunchTemplateIdT = Aws::String>
+    LaunchTemplateSpecificationOverride& WithLaunchTemplateId(LaunchTemplateIdT&& value) { SetLaunchTemplateId(std::forward<LaunchTemplateIdT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -73,14 +71,12 @@ namespace Model
      * <code>launchTemplateName</code> you can't specify the
      * <code>launchTemplateId</code> as well.</p>
      */
-    inline const Aws::String& GetLaunchTemplateName() const{ return m_launchTemplateName; }
+    inline const Aws::String& GetLaunchTemplateName() const { return m_launchTemplateName; }
     inline bool LaunchTemplateNameHasBeenSet() const { return m_launchTemplateNameHasBeenSet; }
-    inline void SetLaunchTemplateName(const Aws::String& value) { m_launchTemplateNameHasBeenSet = true; m_launchTemplateName = value; }
-    inline void SetLaunchTemplateName(Aws::String&& value) { m_launchTemplateNameHasBeenSet = true; m_launchTemplateName = std::move(value); }
-    inline void SetLaunchTemplateName(const char* value) { m_launchTemplateNameHasBeenSet = true; m_launchTemplateName.assign(value); }
-    inline LaunchTemplateSpecificationOverride& WithLaunchTemplateName(const Aws::String& value) { SetLaunchTemplateName(value); return *this;}
-    inline LaunchTemplateSpecificationOverride& WithLaunchTemplateName(Aws::String&& value) { SetLaunchTemplateName(std::move(value)); return *this;}
-    inline LaunchTemplateSpecificationOverride& WithLaunchTemplateName(const char* value) { SetLaunchTemplateName(value); return *this;}
+    template<typename LaunchTemplateNameT = Aws::String>
+    void SetLaunchTemplateName(LaunchTemplateNameT&& value) { m_launchTemplateNameHasBeenSet = true; m_launchTemplateName = std::forward<LaunchTemplateNameT>(value); }
+    template<typename LaunchTemplateNameT = Aws::String>
+    LaunchTemplateSpecificationOverride& WithLaunchTemplateName(LaunchTemplateNameT&& value) { SetLaunchTemplateName(std::forward<LaunchTemplateNameT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -103,14 +99,12 @@ namespace Model
      * compute environments</a> in the <i>Batch User Guide</i>.</p> 
      * <p>Default: <code>$Default</code> </p> <p>Latest: <code>$Latest</code> </p>
      */
-    inline const Aws::String& GetVersion() const{ return m_version; }
+    inline const Aws::String& GetVersion() const { return m_version; }
     inline bool VersionHasBeenSet() const { return m_versionHasBeenSet; }
-    inline void SetVersion(const Aws::String& value) { m_versionHasBeenSet = true; m_version = value; }
-    inline void SetVersion(Aws::String&& value) { m_versionHasBeenSet = true; m_version = std::move(value); }
-    inline void SetVersion(const char* value) { m_versionHasBeenSet = true; m_version.assign(value); }
-    inline LaunchTemplateSpecificationOverride& WithVersion(const Aws::String& value) { SetVersion(value); return *this;}
-    inline LaunchTemplateSpecificationOverride& WithVersion(Aws::String&& value) { SetVersion(std::move(value)); return *this;}
-    inline LaunchTemplateSpecificationOverride& WithVersion(const char* value) { SetVersion(value); return *this;}
+    template<typename VersionT = Aws::String>
+    void SetVersion(VersionT&& value) { m_versionHasBeenSet = true; m_version = std::forward<VersionT>(value); }
+    template<typename VersionT = Aws::String>
+    LaunchTemplateSpecificationOverride& WithVersion(VersionT&& value) { SetVersion(std::forward<VersionT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -135,15 +129,14 @@ namespace Model
      * target an instance family and another define an instance type within this same
      * family.</p> </li> </ul>
      */
-    inline const Aws::Vector<Aws::String>& GetTargetInstanceTypes() const{ return m_targetInstanceTypes; }
+    inline const Aws::Vector<Aws::String>& GetTargetInstanceTypes() const { return m_targetInstanceTypes; }
     inline bool TargetInstanceTypesHasBeenSet() const { return m_targetInstanceTypesHasBeenSet; }
-    inline void SetTargetInstanceTypes(const Aws::Vector<Aws::String>& value) { m_targetInstanceTypesHasBeenSet = true; m_targetInstanceTypes = value; }
-    inline void SetTargetInstanceTypes(Aws::Vector<Aws::String>&& value) { m_targetInstanceTypesHasBeenSet = true; m_targetInstanceTypes = std::move(value); }
-    inline LaunchTemplateSpecificationOverride& WithTargetInstanceTypes(const Aws::Vector<Aws::String>& value) { SetTargetInstanceTypes(value); return *this;}
-    inline LaunchTemplateSpecificationOverride& WithTargetInstanceTypes(Aws::Vector<Aws::String>&& value) { SetTargetInstanceTypes(std::move(value)); return *this;}
-    inline LaunchTemplateSpecificationOverride& AddTargetInstanceTypes(const Aws::String& value) { m_targetInstanceTypesHasBeenSet = true; m_targetInstanceTypes.push_back(value); return *this; }
-    inline LaunchTemplateSpecificationOverride& AddTargetInstanceTypes(Aws::String&& value) { m_targetInstanceTypesHasBeenSet = true; m_targetInstanceTypes.push_back(std::move(value)); return *this; }
-    inline LaunchTemplateSpecificationOverride& AddTargetInstanceTypes(const char* value) { m_targetInstanceTypesHasBeenSet = true; m_targetInstanceTypes.push_back(value); return *this; }
+    template<typename TargetInstanceTypesT = Aws::Vector<Aws::String>>
+    void SetTargetInstanceTypes(TargetInstanceTypesT&& value) { m_targetInstanceTypesHasBeenSet = true; m_targetInstanceTypes = std::forward<TargetInstanceTypesT>(value); }
+    template<typename TargetInstanceTypesT = Aws::Vector<Aws::String>>
+    LaunchTemplateSpecificationOverride& WithTargetInstanceTypes(TargetInstanceTypesT&& value) { SetTargetInstanceTypes(std::forward<TargetInstanceTypesT>(value)); return *this;}
+    template<typename TargetInstanceTypesT = Aws::String>
+    LaunchTemplateSpecificationOverride& AddTargetInstanceTypes(TargetInstanceTypesT&& value) { m_targetInstanceTypesHasBeenSet = true; m_targetInstanceTypes.emplace_back(std::forward<TargetInstanceTypesT>(value)); return *this; }
     ///@}
   private:
 
