@@ -24,7 +24,7 @@ namespace Model
   class ApplyPendingMaintenanceActionRequest : public DatabaseMigrationServiceRequest
   {
   public:
-    AWS_DATABASEMIGRATIONSERVICE_API ApplyPendingMaintenanceActionRequest();
+    AWS_DATABASEMIGRATIONSERVICE_API ApplyPendingMaintenanceActionRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -42,14 +42,12 @@ namespace Model
      * <p>The Amazon Resource Name (ARN) of the DMS resource that the pending
      * maintenance action applies to.</p>
      */
-    inline const Aws::String& GetReplicationInstanceArn() const{ return m_replicationInstanceArn; }
+    inline const Aws::String& GetReplicationInstanceArn() const { return m_replicationInstanceArn; }
     inline bool ReplicationInstanceArnHasBeenSet() const { return m_replicationInstanceArnHasBeenSet; }
-    inline void SetReplicationInstanceArn(const Aws::String& value) { m_replicationInstanceArnHasBeenSet = true; m_replicationInstanceArn = value; }
-    inline void SetReplicationInstanceArn(Aws::String&& value) { m_replicationInstanceArnHasBeenSet = true; m_replicationInstanceArn = std::move(value); }
-    inline void SetReplicationInstanceArn(const char* value) { m_replicationInstanceArnHasBeenSet = true; m_replicationInstanceArn.assign(value); }
-    inline ApplyPendingMaintenanceActionRequest& WithReplicationInstanceArn(const Aws::String& value) { SetReplicationInstanceArn(value); return *this;}
-    inline ApplyPendingMaintenanceActionRequest& WithReplicationInstanceArn(Aws::String&& value) { SetReplicationInstanceArn(std::move(value)); return *this;}
-    inline ApplyPendingMaintenanceActionRequest& WithReplicationInstanceArn(const char* value) { SetReplicationInstanceArn(value); return *this;}
+    template<typename ReplicationInstanceArnT = Aws::String>
+    void SetReplicationInstanceArn(ReplicationInstanceArnT&& value) { m_replicationInstanceArnHasBeenSet = true; m_replicationInstanceArn = std::forward<ReplicationInstanceArnT>(value); }
+    template<typename ReplicationInstanceArnT = Aws::String>
+    ApplyPendingMaintenanceActionRequest& WithReplicationInstanceArn(ReplicationInstanceArnT&& value) { SetReplicationInstanceArn(std::forward<ReplicationInstanceArnT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -58,14 +56,12 @@ namespace Model
      * values: <code>os-upgrade</code>, <code>system-update</code>,
      * <code>db-upgrade</code>, <code>os-patch</code> </p>
      */
-    inline const Aws::String& GetApplyAction() const{ return m_applyAction; }
+    inline const Aws::String& GetApplyAction() const { return m_applyAction; }
     inline bool ApplyActionHasBeenSet() const { return m_applyActionHasBeenSet; }
-    inline void SetApplyAction(const Aws::String& value) { m_applyActionHasBeenSet = true; m_applyAction = value; }
-    inline void SetApplyAction(Aws::String&& value) { m_applyActionHasBeenSet = true; m_applyAction = std::move(value); }
-    inline void SetApplyAction(const char* value) { m_applyActionHasBeenSet = true; m_applyAction.assign(value); }
-    inline ApplyPendingMaintenanceActionRequest& WithApplyAction(const Aws::String& value) { SetApplyAction(value); return *this;}
-    inline ApplyPendingMaintenanceActionRequest& WithApplyAction(Aws::String&& value) { SetApplyAction(std::move(value)); return *this;}
-    inline ApplyPendingMaintenanceActionRequest& WithApplyAction(const char* value) { SetApplyAction(value); return *this;}
+    template<typename ApplyActionT = Aws::String>
+    void SetApplyAction(ApplyActionT&& value) { m_applyActionHasBeenSet = true; m_applyAction = std::forward<ApplyActionT>(value); }
+    template<typename ApplyActionT = Aws::String>
+    ApplyPendingMaintenanceActionRequest& WithApplyAction(ApplyActionT&& value) { SetApplyAction(std::forward<ApplyActionT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -78,14 +74,12 @@ namespace Model
      * resource.</p> </li> <li> <p> <code>undo-opt-in</code> - Cancel any existing
      * <code>next-maintenance</code> opt-in requests.</p> </li> </ul>
      */
-    inline const Aws::String& GetOptInType() const{ return m_optInType; }
+    inline const Aws::String& GetOptInType() const { return m_optInType; }
     inline bool OptInTypeHasBeenSet() const { return m_optInTypeHasBeenSet; }
-    inline void SetOptInType(const Aws::String& value) { m_optInTypeHasBeenSet = true; m_optInType = value; }
-    inline void SetOptInType(Aws::String&& value) { m_optInTypeHasBeenSet = true; m_optInType = std::move(value); }
-    inline void SetOptInType(const char* value) { m_optInTypeHasBeenSet = true; m_optInType.assign(value); }
-    inline ApplyPendingMaintenanceActionRequest& WithOptInType(const Aws::String& value) { SetOptInType(value); return *this;}
-    inline ApplyPendingMaintenanceActionRequest& WithOptInType(Aws::String&& value) { SetOptInType(std::move(value)); return *this;}
-    inline ApplyPendingMaintenanceActionRequest& WithOptInType(const char* value) { SetOptInType(value); return *this;}
+    template<typename OptInTypeT = Aws::String>
+    void SetOptInType(OptInTypeT&& value) { m_optInTypeHasBeenSet = true; m_optInType = std::forward<OptInTypeT>(value); }
+    template<typename OptInTypeT = Aws::String>
+    ApplyPendingMaintenanceActionRequest& WithOptInType(OptInTypeT&& value) { SetOptInType(std::forward<OptInTypeT>(value)); return *this;}
     ///@}
   private:
 
