@@ -31,7 +31,7 @@ namespace Model
   class Endpoint
   {
   public:
-    AWS_DYNAMODB_API Endpoint();
+    AWS_DYNAMODB_API Endpoint() = default;
     AWS_DYNAMODB_API Endpoint(Aws::Utils::Json::JsonView jsonValue);
     AWS_DYNAMODB_API Endpoint& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_DYNAMODB_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -41,21 +41,19 @@ namespace Model
     /**
      * <p>IP address of the endpoint.</p>
      */
-    inline const Aws::String& GetAddress() const{ return m_address; }
+    inline const Aws::String& GetAddress() const { return m_address; }
     inline bool AddressHasBeenSet() const { return m_addressHasBeenSet; }
-    inline void SetAddress(const Aws::String& value) { m_addressHasBeenSet = true; m_address = value; }
-    inline void SetAddress(Aws::String&& value) { m_addressHasBeenSet = true; m_address = std::move(value); }
-    inline void SetAddress(const char* value) { m_addressHasBeenSet = true; m_address.assign(value); }
-    inline Endpoint& WithAddress(const Aws::String& value) { SetAddress(value); return *this;}
-    inline Endpoint& WithAddress(Aws::String&& value) { SetAddress(std::move(value)); return *this;}
-    inline Endpoint& WithAddress(const char* value) { SetAddress(value); return *this;}
+    template<typename AddressT = Aws::String>
+    void SetAddress(AddressT&& value) { m_addressHasBeenSet = true; m_address = std::forward<AddressT>(value); }
+    template<typename AddressT = Aws::String>
+    Endpoint& WithAddress(AddressT&& value) { SetAddress(std::forward<AddressT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>Endpoint cache time to live (TTL) value.</p>
      */
-    inline long long GetCachePeriodInMinutes() const{ return m_cachePeriodInMinutes; }
+    inline long long GetCachePeriodInMinutes() const { return m_cachePeriodInMinutes; }
     inline bool CachePeriodInMinutesHasBeenSet() const { return m_cachePeriodInMinutesHasBeenSet; }
     inline void SetCachePeriodInMinutes(long long value) { m_cachePeriodInMinutesHasBeenSet = true; m_cachePeriodInMinutes = value; }
     inline Endpoint& WithCachePeriodInMinutes(long long value) { SetCachePeriodInMinutes(value); return *this;}
@@ -65,7 +63,7 @@ namespace Model
     Aws::String m_address;
     bool m_addressHasBeenSet = false;
 
-    long long m_cachePeriodInMinutes;
+    long long m_cachePeriodInMinutes{0};
     bool m_cachePeriodInMinutesHasBeenSet = false;
   };
 
