@@ -32,7 +32,7 @@ namespace Model
   class CreateConnectionOAuthClientRequestParameters
   {
   public:
-    AWS_CLOUDWATCHEVENTS_API CreateConnectionOAuthClientRequestParameters();
+    AWS_CLOUDWATCHEVENTS_API CreateConnectionOAuthClientRequestParameters() = default;
     AWS_CLOUDWATCHEVENTS_API CreateConnectionOAuthClientRequestParameters(Aws::Utils::Json::JsonView jsonValue);
     AWS_CLOUDWATCHEVENTS_API CreateConnectionOAuthClientRequestParameters& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_CLOUDWATCHEVENTS_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,14 +42,12 @@ namespace Model
     /**
      * <p>The client ID to use for OAuth authorization for the connection.</p>
      */
-    inline const Aws::String& GetClientID() const{ return m_clientID; }
+    inline const Aws::String& GetClientID() const { return m_clientID; }
     inline bool ClientIDHasBeenSet() const { return m_clientIDHasBeenSet; }
-    inline void SetClientID(const Aws::String& value) { m_clientIDHasBeenSet = true; m_clientID = value; }
-    inline void SetClientID(Aws::String&& value) { m_clientIDHasBeenSet = true; m_clientID = std::move(value); }
-    inline void SetClientID(const char* value) { m_clientIDHasBeenSet = true; m_clientID.assign(value); }
-    inline CreateConnectionOAuthClientRequestParameters& WithClientID(const Aws::String& value) { SetClientID(value); return *this;}
-    inline CreateConnectionOAuthClientRequestParameters& WithClientID(Aws::String&& value) { SetClientID(std::move(value)); return *this;}
-    inline CreateConnectionOAuthClientRequestParameters& WithClientID(const char* value) { SetClientID(value); return *this;}
+    template<typename ClientIDT = Aws::String>
+    void SetClientID(ClientIDT&& value) { m_clientIDHasBeenSet = true; m_clientID = std::forward<ClientIDT>(value); }
+    template<typename ClientIDT = Aws::String>
+    CreateConnectionOAuthClientRequestParameters& WithClientID(ClientIDT&& value) { SetClientID(std::forward<ClientIDT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -57,14 +55,12 @@ namespace Model
      * <p>The client secret associated with the client ID to use for OAuth
      * authorization for the connection.</p>
      */
-    inline const Aws::String& GetClientSecret() const{ return m_clientSecret; }
+    inline const Aws::String& GetClientSecret() const { return m_clientSecret; }
     inline bool ClientSecretHasBeenSet() const { return m_clientSecretHasBeenSet; }
-    inline void SetClientSecret(const Aws::String& value) { m_clientSecretHasBeenSet = true; m_clientSecret = value; }
-    inline void SetClientSecret(Aws::String&& value) { m_clientSecretHasBeenSet = true; m_clientSecret = std::move(value); }
-    inline void SetClientSecret(const char* value) { m_clientSecretHasBeenSet = true; m_clientSecret.assign(value); }
-    inline CreateConnectionOAuthClientRequestParameters& WithClientSecret(const Aws::String& value) { SetClientSecret(value); return *this;}
-    inline CreateConnectionOAuthClientRequestParameters& WithClientSecret(Aws::String&& value) { SetClientSecret(std::move(value)); return *this;}
-    inline CreateConnectionOAuthClientRequestParameters& WithClientSecret(const char* value) { SetClientSecret(value); return *this;}
+    template<typename ClientSecretT = Aws::String>
+    void SetClientSecret(ClientSecretT&& value) { m_clientSecretHasBeenSet = true; m_clientSecret = std::forward<ClientSecretT>(value); }
+    template<typename ClientSecretT = Aws::String>
+    CreateConnectionOAuthClientRequestParameters& WithClientSecret(ClientSecretT&& value) { SetClientSecret(std::forward<ClientSecretT>(value)); return *this;}
     ///@}
   private:
 
