@@ -34,7 +34,7 @@ namespace Model
   class IngestedFilesSummary
   {
   public:
-    AWS_LOOKOUTEQUIPMENT_API IngestedFilesSummary();
+    AWS_LOOKOUTEQUIPMENT_API IngestedFilesSummary() = default;
     AWS_LOOKOUTEQUIPMENT_API IngestedFilesSummary(Aws::Utils::Json::JsonView jsonValue);
     AWS_LOOKOUTEQUIPMENT_API IngestedFilesSummary& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_LOOKOUTEQUIPMENT_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,7 +44,7 @@ namespace Model
     /**
      * <p>Indicates the total number of files that were submitted for ingestion.</p>
      */
-    inline int GetTotalNumberOfFiles() const{ return m_totalNumberOfFiles; }
+    inline int GetTotalNumberOfFiles() const { return m_totalNumberOfFiles; }
     inline bool TotalNumberOfFilesHasBeenSet() const { return m_totalNumberOfFilesHasBeenSet; }
     inline void SetTotalNumberOfFiles(int value) { m_totalNumberOfFilesHasBeenSet = true; m_totalNumberOfFiles = value; }
     inline IngestedFilesSummary& WithTotalNumberOfFiles(int value) { SetTotalNumberOfFiles(value); return *this;}
@@ -54,7 +54,7 @@ namespace Model
     /**
      * <p>Indicates the number of files that were successfully ingested.</p>
      */
-    inline int GetIngestedNumberOfFiles() const{ return m_ingestedNumberOfFiles; }
+    inline int GetIngestedNumberOfFiles() const { return m_ingestedNumberOfFiles; }
     inline bool IngestedNumberOfFilesHasBeenSet() const { return m_ingestedNumberOfFilesHasBeenSet; }
     inline void SetIngestedNumberOfFiles(int value) { m_ingestedNumberOfFilesHasBeenSet = true; m_ingestedNumberOfFiles = value; }
     inline IngestedFilesSummary& WithIngestedNumberOfFiles(int value) { SetIngestedNumberOfFiles(value); return *this;}
@@ -65,21 +65,21 @@ namespace Model
      * <p>Indicates the number of files that were discarded. A file could be discarded
      * because its format is invalid (for example, a jpg or pdf) or not readable.</p>
      */
-    inline const Aws::Vector<S3Object>& GetDiscardedFiles() const{ return m_discardedFiles; }
+    inline const Aws::Vector<S3Object>& GetDiscardedFiles() const { return m_discardedFiles; }
     inline bool DiscardedFilesHasBeenSet() const { return m_discardedFilesHasBeenSet; }
-    inline void SetDiscardedFiles(const Aws::Vector<S3Object>& value) { m_discardedFilesHasBeenSet = true; m_discardedFiles = value; }
-    inline void SetDiscardedFiles(Aws::Vector<S3Object>&& value) { m_discardedFilesHasBeenSet = true; m_discardedFiles = std::move(value); }
-    inline IngestedFilesSummary& WithDiscardedFiles(const Aws::Vector<S3Object>& value) { SetDiscardedFiles(value); return *this;}
-    inline IngestedFilesSummary& WithDiscardedFiles(Aws::Vector<S3Object>&& value) { SetDiscardedFiles(std::move(value)); return *this;}
-    inline IngestedFilesSummary& AddDiscardedFiles(const S3Object& value) { m_discardedFilesHasBeenSet = true; m_discardedFiles.push_back(value); return *this; }
-    inline IngestedFilesSummary& AddDiscardedFiles(S3Object&& value) { m_discardedFilesHasBeenSet = true; m_discardedFiles.push_back(std::move(value)); return *this; }
+    template<typename DiscardedFilesT = Aws::Vector<S3Object>>
+    void SetDiscardedFiles(DiscardedFilesT&& value) { m_discardedFilesHasBeenSet = true; m_discardedFiles = std::forward<DiscardedFilesT>(value); }
+    template<typename DiscardedFilesT = Aws::Vector<S3Object>>
+    IngestedFilesSummary& WithDiscardedFiles(DiscardedFilesT&& value) { SetDiscardedFiles(std::forward<DiscardedFilesT>(value)); return *this;}
+    template<typename DiscardedFilesT = S3Object>
+    IngestedFilesSummary& AddDiscardedFiles(DiscardedFilesT&& value) { m_discardedFilesHasBeenSet = true; m_discardedFiles.emplace_back(std::forward<DiscardedFilesT>(value)); return *this; }
     ///@}
   private:
 
-    int m_totalNumberOfFiles;
+    int m_totalNumberOfFiles{0};
     bool m_totalNumberOfFilesHasBeenSet = false;
 
-    int m_ingestedNumberOfFiles;
+    int m_ingestedNumberOfFiles{0};
     bool m_ingestedNumberOfFilesHasBeenSet = false;
 
     Aws::Vector<S3Object> m_discardedFiles;
