@@ -39,7 +39,7 @@ namespace Model
   class Av1Settings
   {
   public:
-    AWS_MEDIACONVERT_API Av1Settings();
+    AWS_MEDIACONVERT_API Av1Settings() = default;
     AWS_MEDIACONVERT_API Av1Settings(Aws::Utils::Json::JsonView jsonValue);
     AWS_MEDIACONVERT_API Av1Settings& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_MEDIACONVERT_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -50,24 +50,20 @@ namespace Model
      * Specify the strength of any adaptive quantization filters that you enable. The
      * value that you choose here applies to Spatial adaptive quantization.
      */
-    inline const Av1AdaptiveQuantization& GetAdaptiveQuantization() const{ return m_adaptiveQuantization; }
+    inline Av1AdaptiveQuantization GetAdaptiveQuantization() const { return m_adaptiveQuantization; }
     inline bool AdaptiveQuantizationHasBeenSet() const { return m_adaptiveQuantizationHasBeenSet; }
-    inline void SetAdaptiveQuantization(const Av1AdaptiveQuantization& value) { m_adaptiveQuantizationHasBeenSet = true; m_adaptiveQuantization = value; }
-    inline void SetAdaptiveQuantization(Av1AdaptiveQuantization&& value) { m_adaptiveQuantizationHasBeenSet = true; m_adaptiveQuantization = std::move(value); }
-    inline Av1Settings& WithAdaptiveQuantization(const Av1AdaptiveQuantization& value) { SetAdaptiveQuantization(value); return *this;}
-    inline Av1Settings& WithAdaptiveQuantization(Av1AdaptiveQuantization&& value) { SetAdaptiveQuantization(std::move(value)); return *this;}
+    inline void SetAdaptiveQuantization(Av1AdaptiveQuantization value) { m_adaptiveQuantizationHasBeenSet = true; m_adaptiveQuantization = value; }
+    inline Av1Settings& WithAdaptiveQuantization(Av1AdaptiveQuantization value) { SetAdaptiveQuantization(value); return *this;}
     ///@}
 
     ///@{
     /**
      * Specify the Bit depth. You can choose 8-bit or 10-bit.
      */
-    inline const Av1BitDepth& GetBitDepth() const{ return m_bitDepth; }
+    inline Av1BitDepth GetBitDepth() const { return m_bitDepth; }
     inline bool BitDepthHasBeenSet() const { return m_bitDepthHasBeenSet; }
-    inline void SetBitDepth(const Av1BitDepth& value) { m_bitDepthHasBeenSet = true; m_bitDepth = value; }
-    inline void SetBitDepth(Av1BitDepth&& value) { m_bitDepthHasBeenSet = true; m_bitDepth = std::move(value); }
-    inline Av1Settings& WithBitDepth(const Av1BitDepth& value) { SetBitDepth(value); return *this;}
-    inline Av1Settings& WithBitDepth(Av1BitDepth&& value) { SetBitDepth(std::move(value)); return *this;}
+    inline void SetBitDepth(Av1BitDepth value) { m_bitDepthHasBeenSet = true; m_bitDepth = value; }
+    inline Av1Settings& WithBitDepth(Av1BitDepth value) { SetBitDepth(value); return *this;}
     ///@}
 
     ///@{
@@ -79,12 +75,10 @@ namespace Model
      * Disabled. When you include Film grain synthesis, you cannot include the Noise
      * reducer preprocessor.
      */
-    inline const Av1FilmGrainSynthesis& GetFilmGrainSynthesis() const{ return m_filmGrainSynthesis; }
+    inline Av1FilmGrainSynthesis GetFilmGrainSynthesis() const { return m_filmGrainSynthesis; }
     inline bool FilmGrainSynthesisHasBeenSet() const { return m_filmGrainSynthesisHasBeenSet; }
-    inline void SetFilmGrainSynthesis(const Av1FilmGrainSynthesis& value) { m_filmGrainSynthesisHasBeenSet = true; m_filmGrainSynthesis = value; }
-    inline void SetFilmGrainSynthesis(Av1FilmGrainSynthesis&& value) { m_filmGrainSynthesisHasBeenSet = true; m_filmGrainSynthesis = std::move(value); }
-    inline Av1Settings& WithFilmGrainSynthesis(const Av1FilmGrainSynthesis& value) { SetFilmGrainSynthesis(value); return *this;}
-    inline Av1Settings& WithFilmGrainSynthesis(Av1FilmGrainSynthesis&& value) { SetFilmGrainSynthesis(std::move(value)); return *this;}
+    inline void SetFilmGrainSynthesis(Av1FilmGrainSynthesis value) { m_filmGrainSynthesisHasBeenSet = true; m_filmGrainSynthesis = value; }
+    inline Av1Settings& WithFilmGrainSynthesis(Av1FilmGrainSynthesis value) { SetFilmGrainSynthesis(value); return *this;}
     ///@}
 
     ///@{
@@ -96,12 +90,10 @@ namespace Model
      * approximations of fractions. If you choose Custom, specify your frame rate as a
      * fraction.
      */
-    inline const Av1FramerateControl& GetFramerateControl() const{ return m_framerateControl; }
+    inline Av1FramerateControl GetFramerateControl() const { return m_framerateControl; }
     inline bool FramerateControlHasBeenSet() const { return m_framerateControlHasBeenSet; }
-    inline void SetFramerateControl(const Av1FramerateControl& value) { m_framerateControlHasBeenSet = true; m_framerateControl = value; }
-    inline void SetFramerateControl(Av1FramerateControl&& value) { m_framerateControlHasBeenSet = true; m_framerateControl = std::move(value); }
-    inline Av1Settings& WithFramerateControl(const Av1FramerateControl& value) { SetFramerateControl(value); return *this;}
-    inline Av1Settings& WithFramerateControl(Av1FramerateControl&& value) { SetFramerateControl(std::move(value)); return *this;}
+    inline void SetFramerateControl(Av1FramerateControl value) { m_framerateControlHasBeenSet = true; m_framerateControl = value; }
+    inline Av1Settings& WithFramerateControl(Av1FramerateControl value) { SetFramerateControl(value); return *this;}
     ///@}
 
     ///@{
@@ -123,12 +115,10 @@ namespace Model
      * duration of your output will become shorter at higher frame rates and longer at
      * lower frame rates.
      */
-    inline const Av1FramerateConversionAlgorithm& GetFramerateConversionAlgorithm() const{ return m_framerateConversionAlgorithm; }
+    inline Av1FramerateConversionAlgorithm GetFramerateConversionAlgorithm() const { return m_framerateConversionAlgorithm; }
     inline bool FramerateConversionAlgorithmHasBeenSet() const { return m_framerateConversionAlgorithmHasBeenSet; }
-    inline void SetFramerateConversionAlgorithm(const Av1FramerateConversionAlgorithm& value) { m_framerateConversionAlgorithmHasBeenSet = true; m_framerateConversionAlgorithm = value; }
-    inline void SetFramerateConversionAlgorithm(Av1FramerateConversionAlgorithm&& value) { m_framerateConversionAlgorithmHasBeenSet = true; m_framerateConversionAlgorithm = std::move(value); }
-    inline Av1Settings& WithFramerateConversionAlgorithm(const Av1FramerateConversionAlgorithm& value) { SetFramerateConversionAlgorithm(value); return *this;}
-    inline Av1Settings& WithFramerateConversionAlgorithm(Av1FramerateConversionAlgorithm&& value) { SetFramerateConversionAlgorithm(std::move(value)); return *this;}
+    inline void SetFramerateConversionAlgorithm(Av1FramerateConversionAlgorithm value) { m_framerateConversionAlgorithmHasBeenSet = true; m_framerateConversionAlgorithm = value; }
+    inline Av1Settings& WithFramerateConversionAlgorithm(Av1FramerateConversionAlgorithm value) { SetFramerateConversionAlgorithm(value); return *this;}
     ///@}
 
     ///@{
@@ -140,7 +130,7 @@ namespace Model
      * console for transcode jobs that use frame rate conversion, provide the value as
      * a decimal number for Framerate. In this example, specify 23.976.
      */
-    inline int GetFramerateDenominator() const{ return m_framerateDenominator; }
+    inline int GetFramerateDenominator() const { return m_framerateDenominator; }
     inline bool FramerateDenominatorHasBeenSet() const { return m_framerateDenominatorHasBeenSet; }
     inline void SetFramerateDenominator(int value) { m_framerateDenominatorHasBeenSet = true; m_framerateDenominator = value; }
     inline Av1Settings& WithFramerateDenominator(int value) { SetFramerateDenominator(value); return *this;}
@@ -155,7 +145,7 @@ namespace Model
      * transcode jobs that use frame rate conversion, provide the value as a decimal
      * number for Framerate. In this example, specify 23.976.
      */
-    inline int GetFramerateNumerator() const{ return m_framerateNumerator; }
+    inline int GetFramerateNumerator() const { return m_framerateNumerator; }
     inline bool FramerateNumeratorHasBeenSet() const { return m_framerateNumeratorHasBeenSet; }
     inline void SetFramerateNumerator(int value) { m_framerateNumeratorHasBeenSet = true; m_framerateNumerator = value; }
     inline Av1Settings& WithFramerateNumerator(int value) { SetFramerateNumerator(value); return *this;}
@@ -167,7 +157,7 @@ namespace Model
      * doesn't support GOP length in seconds. This value must be greater than zero and
      * preferably equal to 1 + ((numberBFrames + 1) * x), where x is an integer value.
      */
-    inline double GetGopSize() const{ return m_gopSize; }
+    inline double GetGopSize() const { return m_gopSize; }
     inline bool GopSizeHasBeenSet() const { return m_gopSizeHasBeenSet; }
     inline void SetGopSize(double value) { m_gopSizeHasBeenSet = true; m_gopSize = value; }
     inline Av1Settings& WithGopSize(double value) { SetGopSize(value); return *this;}
@@ -178,7 +168,7 @@ namespace Model
      * Maximum bitrate in bits/second. For example, enter five megabits per second as
      * 5000000. Required when Rate control mode is QVBR.
      */
-    inline int GetMaxBitrate() const{ return m_maxBitrate; }
+    inline int GetMaxBitrate() const { return m_maxBitrate; }
     inline bool MaxBitrateHasBeenSet() const { return m_maxBitrateHasBeenSet; }
     inline void SetMaxBitrate(int value) { m_maxBitrateHasBeenSet = true; m_maxBitrate = value; }
     inline Av1Settings& WithMaxBitrate(int value) { SetMaxBitrate(value); return *this;}
@@ -190,7 +180,7 @@ namespace Model
      * recommend using 7 or 15. Choose a larger number for a lower bitrate and smaller
      * file size; choose a smaller number for better video quality.
      */
-    inline int GetNumberBFramesBetweenReferenceFrames() const{ return m_numberBFramesBetweenReferenceFrames; }
+    inline int GetNumberBFramesBetweenReferenceFrames() const { return m_numberBFramesBetweenReferenceFrames; }
     inline bool NumberBFramesBetweenReferenceFramesHasBeenSet() const { return m_numberBFramesBetweenReferenceFramesHasBeenSet; }
     inline void SetNumberBFramesBetweenReferenceFrames(int value) { m_numberBFramesBetweenReferenceFramesHasBeenSet = true; m_numberBFramesBetweenReferenceFrames = value; }
     inline Av1Settings& WithNumberBFramesBetweenReferenceFrames(int value) { SetNumberBFramesBetweenReferenceFrames(value); return *this;}
@@ -201,12 +191,12 @@ namespace Model
      * Settings for quality-defined variable bitrate encoding with the H.265 codec. Use
      * these settings only when you set QVBR for Rate control mode.
      */
-    inline const Av1QvbrSettings& GetQvbrSettings() const{ return m_qvbrSettings; }
+    inline const Av1QvbrSettings& GetQvbrSettings() const { return m_qvbrSettings; }
     inline bool QvbrSettingsHasBeenSet() const { return m_qvbrSettingsHasBeenSet; }
-    inline void SetQvbrSettings(const Av1QvbrSettings& value) { m_qvbrSettingsHasBeenSet = true; m_qvbrSettings = value; }
-    inline void SetQvbrSettings(Av1QvbrSettings&& value) { m_qvbrSettingsHasBeenSet = true; m_qvbrSettings = std::move(value); }
-    inline Av1Settings& WithQvbrSettings(const Av1QvbrSettings& value) { SetQvbrSettings(value); return *this;}
-    inline Av1Settings& WithQvbrSettings(Av1QvbrSettings&& value) { SetQvbrSettings(std::move(value)); return *this;}
+    template<typename QvbrSettingsT = Av1QvbrSettings>
+    void SetQvbrSettings(QvbrSettingsT&& value) { m_qvbrSettingsHasBeenSet = true; m_qvbrSettings = std::forward<QvbrSettingsT>(value); }
+    template<typename QvbrSettingsT = Av1QvbrSettings>
+    Av1Settings& WithQvbrSettings(QvbrSettingsT&& value) { SetQvbrSettings(std::forward<QvbrSettingsT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -214,12 +204,10 @@ namespace Model
      * 'With AV1 outputs, for rate control mode, MediaConvert supports only
      * quality-defined variable bitrate (QVBR). You can''t use CBR or VBR.'
      */
-    inline const Av1RateControlMode& GetRateControlMode() const{ return m_rateControlMode; }
+    inline Av1RateControlMode GetRateControlMode() const { return m_rateControlMode; }
     inline bool RateControlModeHasBeenSet() const { return m_rateControlModeHasBeenSet; }
-    inline void SetRateControlMode(const Av1RateControlMode& value) { m_rateControlModeHasBeenSet = true; m_rateControlMode = value; }
-    inline void SetRateControlMode(Av1RateControlMode&& value) { m_rateControlModeHasBeenSet = true; m_rateControlMode = std::move(value); }
-    inline Av1Settings& WithRateControlMode(const Av1RateControlMode& value) { SetRateControlMode(value); return *this;}
-    inline Av1Settings& WithRateControlMode(Av1RateControlMode&& value) { SetRateControlMode(std::move(value)); return *this;}
+    inline void SetRateControlMode(Av1RateControlMode value) { m_rateControlModeHasBeenSet = true; m_rateControlMode = value; }
+    inline Av1Settings& WithRateControlMode(Av1RateControlMode value) { SetRateControlMode(value); return *this;}
     ///@}
 
     ///@{
@@ -229,7 +217,7 @@ namespace Model
      * number of macroblock rows. For interlaced pictures, this value must be less than
      * or equal to half the number of macroblock rows.
      */
-    inline int GetSlices() const{ return m_slices; }
+    inline int GetSlices() const { return m_slices; }
     inline bool SlicesHasBeenSet() const { return m_slicesHasBeenSet; }
     inline void SetSlices(int value) { m_slicesHasBeenSet = true; m_slices = value; }
     inline Av1Settings& WithSlices(int value) { SetSlices(value); return *this;}
@@ -252,55 +240,53 @@ namespace Model
      * as cartoons and video games, set it to Low. For content with a wider variety of
      * textures, set it to High or Higher.
      */
-    inline const Av1SpatialAdaptiveQuantization& GetSpatialAdaptiveQuantization() const{ return m_spatialAdaptiveQuantization; }
+    inline Av1SpatialAdaptiveQuantization GetSpatialAdaptiveQuantization() const { return m_spatialAdaptiveQuantization; }
     inline bool SpatialAdaptiveQuantizationHasBeenSet() const { return m_spatialAdaptiveQuantizationHasBeenSet; }
-    inline void SetSpatialAdaptiveQuantization(const Av1SpatialAdaptiveQuantization& value) { m_spatialAdaptiveQuantizationHasBeenSet = true; m_spatialAdaptiveQuantization = value; }
-    inline void SetSpatialAdaptiveQuantization(Av1SpatialAdaptiveQuantization&& value) { m_spatialAdaptiveQuantizationHasBeenSet = true; m_spatialAdaptiveQuantization = std::move(value); }
-    inline Av1Settings& WithSpatialAdaptiveQuantization(const Av1SpatialAdaptiveQuantization& value) { SetSpatialAdaptiveQuantization(value); return *this;}
-    inline Av1Settings& WithSpatialAdaptiveQuantization(Av1SpatialAdaptiveQuantization&& value) { SetSpatialAdaptiveQuantization(std::move(value)); return *this;}
+    inline void SetSpatialAdaptiveQuantization(Av1SpatialAdaptiveQuantization value) { m_spatialAdaptiveQuantizationHasBeenSet = true; m_spatialAdaptiveQuantization = value; }
+    inline Av1Settings& WithSpatialAdaptiveQuantization(Av1SpatialAdaptiveQuantization value) { SetSpatialAdaptiveQuantization(value); return *this;}
     ///@}
   private:
 
-    Av1AdaptiveQuantization m_adaptiveQuantization;
+    Av1AdaptiveQuantization m_adaptiveQuantization{Av1AdaptiveQuantization::NOT_SET};
     bool m_adaptiveQuantizationHasBeenSet = false;
 
-    Av1BitDepth m_bitDepth;
+    Av1BitDepth m_bitDepth{Av1BitDepth::NOT_SET};
     bool m_bitDepthHasBeenSet = false;
 
-    Av1FilmGrainSynthesis m_filmGrainSynthesis;
+    Av1FilmGrainSynthesis m_filmGrainSynthesis{Av1FilmGrainSynthesis::NOT_SET};
     bool m_filmGrainSynthesisHasBeenSet = false;
 
-    Av1FramerateControl m_framerateControl;
+    Av1FramerateControl m_framerateControl{Av1FramerateControl::NOT_SET};
     bool m_framerateControlHasBeenSet = false;
 
-    Av1FramerateConversionAlgorithm m_framerateConversionAlgorithm;
+    Av1FramerateConversionAlgorithm m_framerateConversionAlgorithm{Av1FramerateConversionAlgorithm::NOT_SET};
     bool m_framerateConversionAlgorithmHasBeenSet = false;
 
-    int m_framerateDenominator;
+    int m_framerateDenominator{0};
     bool m_framerateDenominatorHasBeenSet = false;
 
-    int m_framerateNumerator;
+    int m_framerateNumerator{0};
     bool m_framerateNumeratorHasBeenSet = false;
 
-    double m_gopSize;
+    double m_gopSize{0.0};
     bool m_gopSizeHasBeenSet = false;
 
-    int m_maxBitrate;
+    int m_maxBitrate{0};
     bool m_maxBitrateHasBeenSet = false;
 
-    int m_numberBFramesBetweenReferenceFrames;
+    int m_numberBFramesBetweenReferenceFrames{0};
     bool m_numberBFramesBetweenReferenceFramesHasBeenSet = false;
 
     Av1QvbrSettings m_qvbrSettings;
     bool m_qvbrSettingsHasBeenSet = false;
 
-    Av1RateControlMode m_rateControlMode;
+    Av1RateControlMode m_rateControlMode{Av1RateControlMode::NOT_SET};
     bool m_rateControlModeHasBeenSet = false;
 
-    int m_slices;
+    int m_slices{0};
     bool m_slicesHasBeenSet = false;
 
-    Av1SpatialAdaptiveQuantization m_spatialAdaptiveQuantization;
+    Av1SpatialAdaptiveQuantization m_spatialAdaptiveQuantization{Av1SpatialAdaptiveQuantization::NOT_SET};
     bool m_spatialAdaptiveQuantizationHasBeenSet = false;
   };
 
