@@ -24,7 +24,7 @@ namespace Model
   class CreateEngagementRequest : public PartnerCentralSellingRequest
   {
   public:
-    AWS_PARTNERCENTRALSELLING_API CreateEngagementRequest();
+    AWS_PARTNERCENTRALSELLING_API CreateEngagementRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -44,14 +44,12 @@ namespace Model
      * <code>Sandbox</code>, which determine the environment in which the engagement is
      * managed.</p>
      */
-    inline const Aws::String& GetCatalog() const{ return m_catalog; }
+    inline const Aws::String& GetCatalog() const { return m_catalog; }
     inline bool CatalogHasBeenSet() const { return m_catalogHasBeenSet; }
-    inline void SetCatalog(const Aws::String& value) { m_catalogHasBeenSet = true; m_catalog = value; }
-    inline void SetCatalog(Aws::String&& value) { m_catalogHasBeenSet = true; m_catalog = std::move(value); }
-    inline void SetCatalog(const char* value) { m_catalogHasBeenSet = true; m_catalog.assign(value); }
-    inline CreateEngagementRequest& WithCatalog(const Aws::String& value) { SetCatalog(value); return *this;}
-    inline CreateEngagementRequest& WithCatalog(Aws::String&& value) { SetCatalog(std::move(value)); return *this;}
-    inline CreateEngagementRequest& WithCatalog(const char* value) { SetCatalog(value); return *this;}
+    template<typename CatalogT = Aws::String>
+    void SetCatalog(CatalogT&& value) { m_catalogHasBeenSet = true; m_catalog = std::forward<CatalogT>(value); }
+    template<typename CatalogT = Aws::String>
+    CreateEngagementRequest& WithCatalog(CatalogT&& value) { SetCatalog(std::forward<CatalogT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -60,14 +58,12 @@ namespace Model
      * unique, case-sensitive identifier to ensure that the request is handled exactly
      * once. The value must not exceed sixty-four alphanumeric characters.</p>
      */
-    inline const Aws::String& GetClientToken() const{ return m_clientToken; }
+    inline const Aws::String& GetClientToken() const { return m_clientToken; }
     inline bool ClientTokenHasBeenSet() const { return m_clientTokenHasBeenSet; }
-    inline void SetClientToken(const Aws::String& value) { m_clientTokenHasBeenSet = true; m_clientToken = value; }
-    inline void SetClientToken(Aws::String&& value) { m_clientTokenHasBeenSet = true; m_clientToken = std::move(value); }
-    inline void SetClientToken(const char* value) { m_clientTokenHasBeenSet = true; m_clientToken.assign(value); }
-    inline CreateEngagementRequest& WithClientToken(const Aws::String& value) { SetClientToken(value); return *this;}
-    inline CreateEngagementRequest& WithClientToken(Aws::String&& value) { SetClientToken(std::move(value)); return *this;}
-    inline CreateEngagementRequest& WithClientToken(const char* value) { SetClientToken(value); return *this;}
+    template<typename ClientTokenT = Aws::String>
+    void SetClientToken(ClientTokenT&& value) { m_clientTokenHasBeenSet = true; m_clientToken = std::forward<ClientTokenT>(value); }
+    template<typename ClientTokenT = Aws::String>
+    CreateEngagementRequest& WithClientToken(ClientTokenT&& value) { SetClientToken(std::forward<ClientTokenT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -89,42 +85,38 @@ namespace Model
      * effective collaboration between parties by providing relevant customer and
      * project information.</p>
      */
-    inline const Aws::Vector<EngagementContextDetails>& GetContexts() const{ return m_contexts; }
+    inline const Aws::Vector<EngagementContextDetails>& GetContexts() const { return m_contexts; }
     inline bool ContextsHasBeenSet() const { return m_contextsHasBeenSet; }
-    inline void SetContexts(const Aws::Vector<EngagementContextDetails>& value) { m_contextsHasBeenSet = true; m_contexts = value; }
-    inline void SetContexts(Aws::Vector<EngagementContextDetails>&& value) { m_contextsHasBeenSet = true; m_contexts = std::move(value); }
-    inline CreateEngagementRequest& WithContexts(const Aws::Vector<EngagementContextDetails>& value) { SetContexts(value); return *this;}
-    inline CreateEngagementRequest& WithContexts(Aws::Vector<EngagementContextDetails>&& value) { SetContexts(std::move(value)); return *this;}
-    inline CreateEngagementRequest& AddContexts(const EngagementContextDetails& value) { m_contextsHasBeenSet = true; m_contexts.push_back(value); return *this; }
-    inline CreateEngagementRequest& AddContexts(EngagementContextDetails&& value) { m_contextsHasBeenSet = true; m_contexts.push_back(std::move(value)); return *this; }
+    template<typename ContextsT = Aws::Vector<EngagementContextDetails>>
+    void SetContexts(ContextsT&& value) { m_contextsHasBeenSet = true; m_contexts = std::forward<ContextsT>(value); }
+    template<typename ContextsT = Aws::Vector<EngagementContextDetails>>
+    CreateEngagementRequest& WithContexts(ContextsT&& value) { SetContexts(std::forward<ContextsT>(value)); return *this;}
+    template<typename ContextsT = EngagementContextDetails>
+    CreateEngagementRequest& AddContexts(ContextsT&& value) { m_contextsHasBeenSet = true; m_contexts.emplace_back(std::forward<ContextsT>(value)); return *this; }
     ///@}
 
     ///@{
     /**
      * <p>Provides a description of the <code>Engagement</code>.</p>
      */
-    inline const Aws::String& GetDescription() const{ return m_description; }
+    inline const Aws::String& GetDescription() const { return m_description; }
     inline bool DescriptionHasBeenSet() const { return m_descriptionHasBeenSet; }
-    inline void SetDescription(const Aws::String& value) { m_descriptionHasBeenSet = true; m_description = value; }
-    inline void SetDescription(Aws::String&& value) { m_descriptionHasBeenSet = true; m_description = std::move(value); }
-    inline void SetDescription(const char* value) { m_descriptionHasBeenSet = true; m_description.assign(value); }
-    inline CreateEngagementRequest& WithDescription(const Aws::String& value) { SetDescription(value); return *this;}
-    inline CreateEngagementRequest& WithDescription(Aws::String&& value) { SetDescription(std::move(value)); return *this;}
-    inline CreateEngagementRequest& WithDescription(const char* value) { SetDescription(value); return *this;}
+    template<typename DescriptionT = Aws::String>
+    void SetDescription(DescriptionT&& value) { m_descriptionHasBeenSet = true; m_description = std::forward<DescriptionT>(value); }
+    template<typename DescriptionT = Aws::String>
+    CreateEngagementRequest& WithDescription(DescriptionT&& value) { SetDescription(std::forward<DescriptionT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>Specifies the title of the <code>Engagement</code>.</p>
      */
-    inline const Aws::String& GetTitle() const{ return m_title; }
+    inline const Aws::String& GetTitle() const { return m_title; }
     inline bool TitleHasBeenSet() const { return m_titleHasBeenSet; }
-    inline void SetTitle(const Aws::String& value) { m_titleHasBeenSet = true; m_title = value; }
-    inline void SetTitle(Aws::String&& value) { m_titleHasBeenSet = true; m_title = std::move(value); }
-    inline void SetTitle(const char* value) { m_titleHasBeenSet = true; m_title.assign(value); }
-    inline CreateEngagementRequest& WithTitle(const Aws::String& value) { SetTitle(value); return *this;}
-    inline CreateEngagementRequest& WithTitle(Aws::String&& value) { SetTitle(std::move(value)); return *this;}
-    inline CreateEngagementRequest& WithTitle(const char* value) { SetTitle(value); return *this;}
+    template<typename TitleT = Aws::String>
+    void SetTitle(TitleT&& value) { m_titleHasBeenSet = true; m_title = std::forward<TitleT>(value); }
+    template<typename TitleT = Aws::String>
+    CreateEngagementRequest& WithTitle(TitleT&& value) { SetTitle(std::forward<TitleT>(value)); return *this;}
     ///@}
   private:
 
