@@ -25,7 +25,7 @@ namespace Model
   class DeleteNetworkRequest : public PrivateNetworksRequest
   {
   public:
-    AWS_PRIVATENETWORKS_API DeleteNetworkRequest();
+    AWS_PRIVATENETWORKS_API DeleteNetworkRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -45,28 +45,24 @@ namespace Model
      * href="https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Run_Instance_Idempotency.html">How
      * to ensure idempotency</a>.</p>
      */
-    inline const Aws::String& GetClientToken() const{ return m_clientToken; }
+    inline const Aws::String& GetClientToken() const { return m_clientToken; }
     inline bool ClientTokenHasBeenSet() const { return m_clientTokenHasBeenSet; }
-    inline void SetClientToken(const Aws::String& value) { m_clientTokenHasBeenSet = true; m_clientToken = value; }
-    inline void SetClientToken(Aws::String&& value) { m_clientTokenHasBeenSet = true; m_clientToken = std::move(value); }
-    inline void SetClientToken(const char* value) { m_clientTokenHasBeenSet = true; m_clientToken.assign(value); }
-    inline DeleteNetworkRequest& WithClientToken(const Aws::String& value) { SetClientToken(value); return *this;}
-    inline DeleteNetworkRequest& WithClientToken(Aws::String&& value) { SetClientToken(std::move(value)); return *this;}
-    inline DeleteNetworkRequest& WithClientToken(const char* value) { SetClientToken(value); return *this;}
+    template<typename ClientTokenT = Aws::String>
+    void SetClientToken(ClientTokenT&& value) { m_clientTokenHasBeenSet = true; m_clientToken = std::forward<ClientTokenT>(value); }
+    template<typename ClientTokenT = Aws::String>
+    DeleteNetworkRequest& WithClientToken(ClientTokenT&& value) { SetClientToken(std::forward<ClientTokenT>(value)); return *this;}
     ///@}
 
     ///@{
     /**
      * <p>The Amazon Resource Name (ARN) of the network.</p>
      */
-    inline const Aws::String& GetNetworkArn() const{ return m_networkArn; }
+    inline const Aws::String& GetNetworkArn() const { return m_networkArn; }
     inline bool NetworkArnHasBeenSet() const { return m_networkArnHasBeenSet; }
-    inline void SetNetworkArn(const Aws::String& value) { m_networkArnHasBeenSet = true; m_networkArn = value; }
-    inline void SetNetworkArn(Aws::String&& value) { m_networkArnHasBeenSet = true; m_networkArn = std::move(value); }
-    inline void SetNetworkArn(const char* value) { m_networkArnHasBeenSet = true; m_networkArn.assign(value); }
-    inline DeleteNetworkRequest& WithNetworkArn(const Aws::String& value) { SetNetworkArn(value); return *this;}
-    inline DeleteNetworkRequest& WithNetworkArn(Aws::String&& value) { SetNetworkArn(std::move(value)); return *this;}
-    inline DeleteNetworkRequest& WithNetworkArn(const char* value) { SetNetworkArn(value); return *this;}
+    template<typename NetworkArnT = Aws::String>
+    void SetNetworkArn(NetworkArnT&& value) { m_networkArnHasBeenSet = true; m_networkArn = std::forward<NetworkArnT>(value); }
+    template<typename NetworkArnT = Aws::String>
+    DeleteNetworkRequest& WithNetworkArn(NetworkArnT&& value) { SetNetworkArn(std::forward<NetworkArnT>(value)); return *this;}
     ///@}
   private:
 
