@@ -30,7 +30,7 @@ namespace Model
   class AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails
   {
   public:
-    AWS_SECURITYHUB_API AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails();
+    AWS_SECURITYHUB_API AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails() = default;
     AWS_SECURITYHUB_API AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SECURITYHUB_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -42,14 +42,14 @@ namespace Model
      * monitoring.</p> <p>If set to <code>false</code>, then instances in the group
      * launch with basic monitoring.</p>
      */
-    inline bool GetEnabled() const{ return m_enabled; }
+    inline bool GetEnabled() const { return m_enabled; }
     inline bool EnabledHasBeenSet() const { return m_enabledHasBeenSet; }
     inline void SetEnabled(bool value) { m_enabledHasBeenSet = true; m_enabled = value; }
     inline AwsAutoScalingLaunchConfigurationInstanceMonitoringDetails& WithEnabled(bool value) { SetEnabled(value); return *this;}
     ///@}
   private:
 
-    bool m_enabled;
+    bool m_enabled{false};
     bool m_enabledHasBeenSet = false;
   };
 
