@@ -9,6 +9,7 @@
 #include <aws/sesv2/model/Body.h>
 #include <aws/core/utils/memory/stl/AWSVector.h>
 #include <aws/sesv2/model/MessageHeader.h>
+#include <aws/sesv2/model/Attachment.h>
 #include <utility>
 
 namespace Aws
@@ -82,6 +83,21 @@ namespace Model
     template<typename HeadersT = MessageHeader>
     Message& AddHeaders(HeadersT&& value) { m_headersHasBeenSet = true; m_headers.emplace_back(std::forward<HeadersT>(value)); return *this; }
     ///@}
+
+    ///@{
+    /**
+     * <p> The List of attachments to include in your email. All recipients will
+     * receive the same attachments.</p>
+     */
+    inline const Aws::Vector<Attachment>& GetAttachments() const { return m_attachments; }
+    inline bool AttachmentsHasBeenSet() const { return m_attachmentsHasBeenSet; }
+    template<typename AttachmentsT = Aws::Vector<Attachment>>
+    void SetAttachments(AttachmentsT&& value) { m_attachmentsHasBeenSet = true; m_attachments = std::forward<AttachmentsT>(value); }
+    template<typename AttachmentsT = Aws::Vector<Attachment>>
+    Message& WithAttachments(AttachmentsT&& value) { SetAttachments(std::forward<AttachmentsT>(value)); return *this;}
+    template<typename AttachmentsT = Attachment>
+    Message& AddAttachments(AttachmentsT&& value) { m_attachmentsHasBeenSet = true; m_attachments.emplace_back(std::forward<AttachmentsT>(value)); return *this; }
+    ///@}
   private:
 
     Content m_subject;
@@ -92,6 +108,9 @@ namespace Model
 
     Aws::Vector<MessageHeader> m_headers;
     bool m_headersHasBeenSet = false;
+
+    Aws::Vector<Attachment> m_attachments;
+    bool m_attachmentsHasBeenSet = false;
   };
 
 } // namespace Model
