@@ -23,7 +23,7 @@ namespace Model
   class ListOpsItemEventsRequest : public SSMRequest
   {
   public:
-    AWS_SSM_API ListOpsItemEventsRequest();
+    AWS_SSM_API ListOpsItemEventsRequest() = default;
 
     // Service request name is the Operation name which will send this request out,
     // each operation should has unique request name, so that we can get operation's name from this request.
@@ -41,14 +41,14 @@ namespace Model
      * <p>One or more OpsItem filters. Use a filter to return a more specific list of
      * results. </p>
      */
-    inline const Aws::Vector<OpsItemEventFilter>& GetFilters() const{ return m_filters; }
+    inline const Aws::Vector<OpsItemEventFilter>& GetFilters() const { return m_filters; }
     inline bool FiltersHasBeenSet() const { return m_filtersHasBeenSet; }
-    inline void SetFilters(const Aws::Vector<OpsItemEventFilter>& value) { m_filtersHasBeenSet = true; m_filters = value; }
-    inline void SetFilters(Aws::Vector<OpsItemEventFilter>&& value) { m_filtersHasBeenSet = true; m_filters = std::move(value); }
-    inline ListOpsItemEventsRequest& WithFilters(const Aws::Vector<OpsItemEventFilter>& value) { SetFilters(value); return *this;}
-    inline ListOpsItemEventsRequest& WithFilters(Aws::Vector<OpsItemEventFilter>&& value) { SetFilters(std::move(value)); return *this;}
-    inline ListOpsItemEventsRequest& AddFilters(const OpsItemEventFilter& value) { m_filtersHasBeenSet = true; m_filters.push_back(value); return *this; }
-    inline ListOpsItemEventsRequest& AddFilters(OpsItemEventFilter&& value) { m_filtersHasBeenSet = true; m_filters.push_back(std::move(value)); return *this; }
+    template<typename FiltersT = Aws::Vector<OpsItemEventFilter>>
+    void SetFilters(FiltersT&& value) { m_filtersHasBeenSet = true; m_filters = std::forward<FiltersT>(value); }
+    template<typename FiltersT = Aws::Vector<OpsItemEventFilter>>
+    ListOpsItemEventsRequest& WithFilters(FiltersT&& value) { SetFilters(std::forward<FiltersT>(value)); return *this;}
+    template<typename FiltersT = OpsItemEventFilter>
+    ListOpsItemEventsRequest& AddFilters(FiltersT&& value) { m_filtersHasBeenSet = true; m_filters.emplace_back(std::forward<FiltersT>(value)); return *this; }
     ///@}
 
     ///@{
@@ -57,7 +57,7 @@ namespace Model
      * token that you can specify in a subsequent call to get the next set of results.
      * </p>
      */
-    inline int GetMaxResults() const{ return m_maxResults; }
+    inline int GetMaxResults() const { return m_maxResults; }
     inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }
     inline void SetMaxResults(int value) { m_maxResultsHasBeenSet = true; m_maxResults = value; }
     inline ListOpsItemEventsRequest& WithMaxResults(int value) { SetMaxResults(value); return *this;}
@@ -68,21 +68,19 @@ namespace Model
      * <p>A token to start the list. Use this token to get the next set of results.
      * </p>
      */
-    inline const Aws::String& GetNextToken() const{ return m_nextToken; }
+    inline const Aws::String& GetNextToken() const { return m_nextToken; }
     inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }
-    inline void SetNextToken(const Aws::String& value) { m_nextTokenHasBeenSet = true; m_nextToken = value; }
-    inline void SetNextToken(Aws::String&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::move(value); }
-    inline void SetNextToken(const char* value) { m_nextTokenHasBeenSet = true; m_nextToken.assign(value); }
-    inline ListOpsItemEventsRequest& WithNextToken(const Aws::String& value) { SetNextToken(value); return *this;}
-    inline ListOpsItemEventsRequest& WithNextToken(Aws::String&& value) { SetNextToken(std::move(value)); return *this;}
-    inline ListOpsItemEventsRequest& WithNextToken(const char* value) { SetNextToken(value); return *this;}
+    template<typename NextTokenT = Aws::String>
+    void SetNextToken(NextTokenT&& value) { m_nextTokenHasBeenSet = true; m_nextToken = std::forward<NextTokenT>(value); }
+    template<typename NextTokenT = Aws::String>
+    ListOpsItemEventsRequest& WithNextToken(NextTokenT&& value) { SetNextToken(std::forward<NextTokenT>(value)); return *this;}
     ///@}
   private:
 
     Aws::Vector<OpsItemEventFilter> m_filters;
     bool m_filtersHasBeenSet = false;
 
-    int m_maxResults;
+    int m_maxResults{0};
     bool m_maxResultsHasBeenSet = false;
 
     Aws::String m_nextToken;
