@@ -33,7 +33,7 @@ namespace Model
   class PatchFilterGroup
   {
   public:
-    AWS_SSM_API PatchFilterGroup();
+    AWS_SSM_API PatchFilterGroup() = default;
     AWS_SSM_API PatchFilterGroup(Aws::Utils::Json::JsonView jsonValue);
     AWS_SSM_API PatchFilterGroup& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_SSM_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -43,14 +43,14 @@ namespace Model
     /**
      * <p>The set of patch filters that make up the group.</p>
      */
-    inline const Aws::Vector<PatchFilter>& GetPatchFilters() const{ return m_patchFilters; }
+    inline const Aws::Vector<PatchFilter>& GetPatchFilters() const { return m_patchFilters; }
     inline bool PatchFiltersHasBeenSet() const { return m_patchFiltersHasBeenSet; }
-    inline void SetPatchFilters(const Aws::Vector<PatchFilter>& value) { m_patchFiltersHasBeenSet = true; m_patchFilters = value; }
-    inline void SetPatchFilters(Aws::Vector<PatchFilter>&& value) { m_patchFiltersHasBeenSet = true; m_patchFilters = std::move(value); }
-    inline PatchFilterGroup& WithPatchFilters(const Aws::Vector<PatchFilter>& value) { SetPatchFilters(value); return *this;}
-    inline PatchFilterGroup& WithPatchFilters(Aws::Vector<PatchFilter>&& value) { SetPatchFilters(std::move(value)); return *this;}
-    inline PatchFilterGroup& AddPatchFilters(const PatchFilter& value) { m_patchFiltersHasBeenSet = true; m_patchFilters.push_back(value); return *this; }
-    inline PatchFilterGroup& AddPatchFilters(PatchFilter&& value) { m_patchFiltersHasBeenSet = true; m_patchFilters.push_back(std::move(value)); return *this; }
+    template<typename PatchFiltersT = Aws::Vector<PatchFilter>>
+    void SetPatchFilters(PatchFiltersT&& value) { m_patchFiltersHasBeenSet = true; m_patchFilters = std::forward<PatchFiltersT>(value); }
+    template<typename PatchFiltersT = Aws::Vector<PatchFilter>>
+    PatchFilterGroup& WithPatchFilters(PatchFiltersT&& value) { SetPatchFilters(std::forward<PatchFiltersT>(value)); return *this;}
+    template<typename PatchFiltersT = PatchFilter>
+    PatchFilterGroup& AddPatchFilters(PatchFiltersT&& value) { m_patchFiltersHasBeenSet = true; m_patchFilters.emplace_back(std::forward<PatchFiltersT>(value)); return *this; }
     ///@}
   private:
 
