@@ -40,7 +40,7 @@ namespace Model
   class Headers
   {
   public:
-    AWS_WAFV2_API Headers();
+    AWS_WAFV2_API Headers() = default;
     AWS_WAFV2_API Headers(Aws::Utils::Json::JsonView jsonValue);
     AWS_WAFV2_API Headers& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_WAFV2_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -54,12 +54,12 @@ namespace Model
      * JSON: <code>"MatchPattern": { "ExcludedHeaders": [ "KeyToExclude1",
      * "KeyToExclude2" ] }</code> </p>
      */
-    inline const HeaderMatchPattern& GetMatchPattern() const{ return m_matchPattern; }
+    inline const HeaderMatchPattern& GetMatchPattern() const { return m_matchPattern; }
     inline bool MatchPatternHasBeenSet() const { return m_matchPatternHasBeenSet; }
-    inline void SetMatchPattern(const HeaderMatchPattern& value) { m_matchPatternHasBeenSet = true; m_matchPattern = value; }
-    inline void SetMatchPattern(HeaderMatchPattern&& value) { m_matchPatternHasBeenSet = true; m_matchPattern = std::move(value); }
-    inline Headers& WithMatchPattern(const HeaderMatchPattern& value) { SetMatchPattern(value); return *this;}
-    inline Headers& WithMatchPattern(HeaderMatchPattern&& value) { SetMatchPattern(std::move(value)); return *this;}
+    template<typename MatchPatternT = HeaderMatchPattern>
+    void SetMatchPattern(MatchPatternT&& value) { m_matchPatternHasBeenSet = true; m_matchPattern = std::forward<MatchPatternT>(value); }
+    template<typename MatchPatternT = HeaderMatchPattern>
+    Headers& WithMatchPattern(MatchPatternT&& value) { SetMatchPattern(std::forward<MatchPatternT>(value)); return *this;}
     ///@}
 
     ///@{
@@ -72,12 +72,10 @@ namespace Model
      * <code>AND</code> statement to combine two match rules, one that inspects the
      * keys and another that inspects the values. </p>
      */
-    inline const MapMatchScope& GetMatchScope() const{ return m_matchScope; }
+    inline MapMatchScope GetMatchScope() const { return m_matchScope; }
     inline bool MatchScopeHasBeenSet() const { return m_matchScopeHasBeenSet; }
-    inline void SetMatchScope(const MapMatchScope& value) { m_matchScopeHasBeenSet = true; m_matchScope = value; }
-    inline void SetMatchScope(MapMatchScope&& value) { m_matchScopeHasBeenSet = true; m_matchScope = std::move(value); }
-    inline Headers& WithMatchScope(const MapMatchScope& value) { SetMatchScope(value); return *this;}
-    inline Headers& WithMatchScope(MapMatchScope&& value) { SetMatchScope(std::move(value)); return *this;}
+    inline void SetMatchScope(MapMatchScope value) { m_matchScopeHasBeenSet = true; m_matchScope = value; }
+    inline Headers& WithMatchScope(MapMatchScope value) { SetMatchScope(value); return *this;}
     ///@}
 
     ///@{
@@ -93,22 +91,20 @@ namespace Model
      * applies the rule action to the request.</p> </li> <li> <p> <code>NO_MATCH</code>
      * - Treat the web request as not matching the rule statement.</p> </li> </ul>
      */
-    inline const OversizeHandling& GetOversizeHandling() const{ return m_oversizeHandling; }
+    inline OversizeHandling GetOversizeHandling() const { return m_oversizeHandling; }
     inline bool OversizeHandlingHasBeenSet() const { return m_oversizeHandlingHasBeenSet; }
-    inline void SetOversizeHandling(const OversizeHandling& value) { m_oversizeHandlingHasBeenSet = true; m_oversizeHandling = value; }
-    inline void SetOversizeHandling(OversizeHandling&& value) { m_oversizeHandlingHasBeenSet = true; m_oversizeHandling = std::move(value); }
-    inline Headers& WithOversizeHandling(const OversizeHandling& value) { SetOversizeHandling(value); return *this;}
-    inline Headers& WithOversizeHandling(OversizeHandling&& value) { SetOversizeHandling(std::move(value)); return *this;}
+    inline void SetOversizeHandling(OversizeHandling value) { m_oversizeHandlingHasBeenSet = true; m_oversizeHandling = value; }
+    inline Headers& WithOversizeHandling(OversizeHandling value) { SetOversizeHandling(value); return *this;}
     ///@}
   private:
 
     HeaderMatchPattern m_matchPattern;
     bool m_matchPatternHasBeenSet = false;
 
-    MapMatchScope m_matchScope;
+    MapMatchScope m_matchScope{MapMatchScope::NOT_SET};
     bool m_matchScopeHasBeenSet = false;
 
-    OversizeHandling m_oversizeHandling;
+    OversizeHandling m_oversizeHandling{OversizeHandling::NOT_SET};
     bool m_oversizeHandlingHasBeenSet = false;
   };
 
