@@ -33,7 +33,7 @@ namespace Model
   class ResponseTimeRootCause
   {
   public:
-    AWS_XRAY_API ResponseTimeRootCause();
+    AWS_XRAY_API ResponseTimeRootCause() = default;
     AWS_XRAY_API ResponseTimeRootCause(Aws::Utils::Json::JsonView jsonValue);
     AWS_XRAY_API ResponseTimeRootCause& operator=(Aws::Utils::Json::JsonView jsonValue);
     AWS_XRAY_API Aws::Utils::Json::JsonValue Jsonize() const;
@@ -44,21 +44,21 @@ namespace Model
      * <p>A list of corresponding services. A service identifies a segment and contains
      * a name, account ID, type, and inferred flag.</p>
      */
-    inline const Aws::Vector<ResponseTimeRootCauseService>& GetServices() const{ return m_services; }
+    inline const Aws::Vector<ResponseTimeRootCauseService>& GetServices() const { return m_services; }
     inline bool ServicesHasBeenSet() const { return m_servicesHasBeenSet; }
-    inline void SetServices(const Aws::Vector<ResponseTimeRootCauseService>& value) { m_servicesHasBeenSet = true; m_services = value; }
-    inline void SetServices(Aws::Vector<ResponseTimeRootCauseService>&& value) { m_servicesHasBeenSet = true; m_services = std::move(value); }
-    inline ResponseTimeRootCause& WithServices(const Aws::Vector<ResponseTimeRootCauseService>& value) { SetServices(value); return *this;}
-    inline ResponseTimeRootCause& WithServices(Aws::Vector<ResponseTimeRootCauseService>&& value) { SetServices(std::move(value)); return *this;}
-    inline ResponseTimeRootCause& AddServices(const ResponseTimeRootCauseService& value) { m_servicesHasBeenSet = true; m_services.push_back(value); return *this; }
-    inline ResponseTimeRootCause& AddServices(ResponseTimeRootCauseService&& value) { m_servicesHasBeenSet = true; m_services.push_back(std::move(value)); return *this; }
+    template<typename ServicesT = Aws::Vector<ResponseTimeRootCauseService>>
+    void SetServices(ServicesT&& value) { m_servicesHasBeenSet = true; m_services = std::forward<ServicesT>(value); }
+    template<typename ServicesT = Aws::Vector<ResponseTimeRootCauseService>>
+    ResponseTimeRootCause& WithServices(ServicesT&& value) { SetServices(std::forward<ServicesT>(value)); return *this;}
+    template<typename ServicesT = ResponseTimeRootCauseService>
+    ResponseTimeRootCause& AddServices(ServicesT&& value) { m_servicesHasBeenSet = true; m_services.emplace_back(std::forward<ServicesT>(value)); return *this; }
     ///@}
 
     ///@{
     /**
      * <p>A flag that denotes that the root cause impacts the trace client.</p>
      */
-    inline bool GetClientImpacting() const{ return m_clientImpacting; }
+    inline bool GetClientImpacting() const { return m_clientImpacting; }
     inline bool ClientImpactingHasBeenSet() const { return m_clientImpactingHasBeenSet; }
     inline void SetClientImpacting(bool value) { m_clientImpactingHasBeenSet = true; m_clientImpacting = value; }
     inline ResponseTimeRootCause& WithClientImpacting(bool value) { SetClientImpacting(value); return *this;}
@@ -68,7 +68,7 @@ namespace Model
     Aws::Vector<ResponseTimeRootCauseService> m_services;
     bool m_servicesHasBeenSet = false;
 
-    bool m_clientImpacting;
+    bool m_clientImpacting{false};
     bool m_clientImpactingHasBeenSet = false;
   };
 
